@@ -4,13 +4,17 @@ use strict;
 use DBI;
 use Carp;
 use Carp::Assert;
+require Class::WhiteHole;
 use Ima::DBI::utility;
 
 use vars qw($VERSION @ISA);
 
 BEGIN {
-    $VERSION = '0.21';
-    @ISA = qw(DBI);
+    $VERSION = '0.24';
+
+    # We accidentally inherit AutoLoader::AUTOLOAD from DBI.  Send it to
+    # the white hole.
+    @ISA = qw(Class::WhiteHole DBI);
 }
 
 # Magical subclassing magic off DBI.
@@ -448,8 +452,8 @@ sub _mk_sql_closure {
         else {          # $sth defined.
             # Check to see if the handle is active.
             if( $sth->FETCH('Active') ) {
-                Carp::croak("'$sql_name' statement handle is still ".
-                            "active!  Finishing for you.");
+                Carp::carp("'$sql_name' statement handle is still ".
+                           "active!  Finishing for you.");
                 $sth->finish;
             }
         }
@@ -601,22 +605,7 @@ sub DBIwarn {
 Ima::DBI makes some of the methods available to your object that are
 normally only available via the database handle.  In addition, it
 spices up the API a bit.
-
-=cut
-
-################################ Ima::DBI::db #############################
-###################### DBI database handle subclass #######################
-
-package Ima::DBI::db;
-
-use Ima::DBI::utility;
-use Carp::Assert;
-use Carp;
-
-use base qw(DBI::db);  # Uhh, I think that's right.
-
-=pod
-
+ 
 =over 4
 
 =item B<commit>         *UNIMPLEMENTED*
@@ -658,6 +647,17 @@ sub rollback {
     _unimplemented;
 }
 
+################################ Ima::DBI::db #############################
+###################### DBI database handle subclass #######################
+
+package Ima::DBI::db;
+
+use Ima::DBI::utility;
+use Carp::Assert;
+use Carp;
+
+use base qw(DBI::db);  # Uhh, I think that's right.
+
 =pod
 
 =item B<clear_cache>    *UNIMPLEMENTED*
